@@ -1,20 +1,20 @@
 from typing import Optional
-
+from .types import ValueType
 
 class KeyPrompt:
     """Defines a key-value prompt for EzConfig.
 
     Args:
         key (str): Key name, must be str
-        default_value (str, oprional): Will be default value if there is no saved values. Defaults to None.
+        default_value (str, optional): Will be default value if there are no saved values. Defaults to None.
         can_be_empty (bool, optional): True/False. Defaults to True.
-        value_type (str | int | float, optional): Value will be always formated by passed instance. Defaults to str.
+        value_type (ValueType, optional): Value will be passed instance. Defaults to str.
     """        
     def __init__(self,
                  key: str,
                  default_value: Optional[str] = None,
                  can_be_empty: bool = True,
-                 value_type: Optional[str | int | float] = str,
+                 value_type: Optional[ValueType] = str,
     ) -> None:
         self.key = key
         self.default_value = default_value
